@@ -23,7 +23,8 @@ cmake ${CMAKE_ARGS} \
   -DTILEDB_TESTS=OFF \
   -DTILEDB_INSTALL_LIBDIR=lib \
   -DTILEDB_HDFS=ON \
-  -DSANITIZER="OFF;-DCOMPILER_SUPPORTS_AVX2:BOOL=FALSE" \
+  -DSANITIZER=OFF \
+  -DCOMPILER_SUPPORTS_AVX2:BOOL=FALSE \
   -DTILEDB_S3=ON \
   -DTILEDB_SERIALIZATION=ON \
   -DTILEDB_LOG_OUTPUT_ON_FAILURE=ON \
